Package: spNetwork
Type: Package
Title: Spatial Analysis on Network
Version: 0.4.4.7
Authors@R: c(
    person("Jeremy", "Gelb", email = "jeremy.gelb@ucs.inrs.ca",role = c("aut", "cre"), comment = c(ORCID = "0000-0002-7114-2714")),
    person("Philippe", "Apparicio", email="philippe.apparicio@ucs.inrs.ca", role=c("ctb"), comment = c(ORCID = "0000-0001-6466-9342")))
Description: Perform spatial analysis on network.
    Implement several methods for spatial analysis on network: Network Kernel Density estimation, 
    building of spatial matrices based on network distance ('listw' objects from 'spdep' package), K functions estimation 
    for point pattern analysis on network, k nearest neighbours on network, reachable area calculation, and graph generation
    References: Okabe et al (2019) <doi:10.1080/13658810802475491>;
    Okabe et al (2012, ISBN:978-0470770818);Baddeley et al (2015, ISBN:9781482210200).
License: GPL-2
Encoding: UTF-8
LazyData: true
Imports: spdep (>= 1.1.2), igraph (>= 1.2.6), cubature (>= 2.0.4.1),
        future.apply (>= 1.4.0), methods (>= 1.7.1), ggplot2 (>=
        3.3.0), progressr (>= 0.4.0), data.table (>= 1.12.8), Rcpp (>=
        1.0.4.6), Rdpack (>= 2.1.1), dbscan (>= 1.1-8), sf (>= 1.0-3),
        abind (>= 1.4-5), sfheaders (>= 0.4.4), cppRouting (>= 3.1)
Depends: R (>= 3.6)
Suggests: future (>= 1.16.0), testthat (>= 3.0.0), kableExtra (>=
        1.1.0), RColorBrewer (>= 1.1-2), classInt (>= 0.4-3), reshape2
        (>= 1.4.3), rlang (>= 0.4.6), rgl (>= 0.107.14), tmap (>=
        3.3-1), smoothr (>= 0.2.2), tibble (>= 3.2.1), concaveman (>=
        1.1.0), covr (>= 3.5.1), knitr, rmarkdown
RoxygenNote: 7.3.2
VignetteBuilder: knitr
URL: https://jeremygelb.github.io/spNetwork/
BugReports: https://github.com/JeremyGelb/spNetwork/issues
LinkingTo: Rcpp, RcppProgress, RcppArmadillo, BH
RdMacros: Rdpack
Language: en-CA
SystemRequirements: C++17
NeedsCompilation: yes
Packaged: 2025-10-04 22:25:44 UTC; Gelb
Author: Jeremy Gelb [aut, cre] (ORCID: <https://orcid.org/0000-0002-7114-2714>),
  Philippe Apparicio [ctb] (ORCID:
    <https://orcid.org/0000-0001-6466-9342>)
Maintainer: Jeremy Gelb <jeremy.gelb@ucs.inrs.ca>
Repository: CRAN
Date/Publication: 2025-10-05 19:30:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-28 11:44:28 UTC; unix
Archs: spNetwork.so.dSYM
