# Generated by roxygen2: do not edit by hand

export(adaptive_bw_tnkde_cpp)
export(adaptive_bw_tnkde_cpp2)
export(aggregate_points)
export(build_graph)
export(build_graph_cppr)
export(build_graph_directed)
export(bw_cv_likelihood_calc)
export(bw_cv_likelihood_calc.mc)
export(bw_cv_likelihood_calc_tkde)
export(bw_cvl_calc)
export(bw_cvl_calc.mc)
export(bw_tnkde_cv_likelihood_calc)
export(bw_tnkde_cv_likelihood_calc.mc)
export(calcEuclideanDistance3)
export(calc_isochrones)
export(closest_points)
export(continuous_nkde_cpp_arma)
export(continuous_nkde_cpp_arma_sparse)
export(continuous_tnkde_cpp_arma)
export(continuous_tnkde_cpp_arma_sparse)
export(corrfactor_continuous)
export(corrfactor_continuous_sparse)
export(corrfactor_discontinuous)
export(corrfactor_discontinuous_sparse)
export(cosine_kernel)
export(cross_kfunctions)
export(cross_kfunctions.mc)
export(discontinuous_nkde_cpp_arma)
export(discontinuous_nkde_cpp_arma_sparse)
export(discontinuous_tnkde_cpp_arma)
export(discontinuous_tnkde_cpp_arma_sparse)
export(epanechnikov_kernel)
export(gaussian_kernel)
export(gaussian_kernel_scaled)
export(gfunc_counting)
export(gfunc_cpp)
export(gfunc_cpp2)
export(graph_checking)
export(k_nt_functions)
export(k_nt_functions.mc)
export(kfunc_counting)
export(kfunc_cpp)
export(kfunc_cpp2)
export(kfunc_time_counting)
export(kfunctions)
export(kfunctions.mc)
export(kgfunc_counting)
export(kgfunc_cpp2)
export(kgfunc_time_counting)
export(lines_center)
export(lines_direction)
export(lines_extremities)
export(lines_points_along)
export(lixelize_lines)
export(lixelize_lines.mc)
export(network_knn)
export(network_knn.mc)
export(network_listw)
export(network_listw.mc)
export(nkde)
export(nkde.mc)
export(nkde_get_loo_values)
export(nkde_worker)
export(pair_dists)
export(quartic_kernel)
export(rev_matrix)
export(simple_lines)
export(simplify_network)
export(snapPointsToLines2)
export(split_graph_components)
export(split_lines_at_vertex)
export(tkde)
export(tnkde)
export(tnkde.mc)
export(tnkde_get_loo_values)
export(tnkde_get_loo_values2)
export(tnkde_worker_bw_sel)
export(triangle_kernel)
export(tricube_kernel)
export(triweight_kernel)
export(uniform_kernel)
export(worker_adaptive_bw_tnkde)
import(Rcpp)
import(methods)
importFrom(Rcpp,sourceCpp)
importFrom(Rdpack,reprompt)
importFrom(cubature,cubintegrate)
importFrom(data.table,":=")
importFrom(data.table,.N)
importFrom(data.table,.SD)
importFrom(data.table,as.data.table)
importFrom(data.table,data.table)
importFrom(data.table,setDF)
importFrom(data.table,setDT)
importFrom(data.table,transpose)
importFrom(data.table,tstrsplit)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,geom_path)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(grDevices,rgb)
importFrom(graphics,plot)
importFrom(igraph,adjacent_vertices)
importFrom(igraph,distances)
importFrom(igraph,ends)
importFrom(igraph,get.edge.attribute)
importFrom(igraph,get.edge.ids)
importFrom(methods,slot)
importFrom(sf,"st_crs<-")
importFrom(sf,"st_geometry<-")
importFrom(sf,st_as_sf)
importFrom(sf,st_as_sfc)
importFrom(sf,st_as_text)
importFrom(sf,st_bbox)
importFrom(sf,st_boundary)
importFrom(sf,st_buffer)
importFrom(sf,st_cast)
importFrom(sf,st_convex_hull)
importFrom(sf,st_coordinates)
importFrom(sf,st_crs)
importFrom(sf,st_distance)
importFrom(sf,st_drop_geometry)
importFrom(sf,st_geometry)
importFrom(sf,st_geometry_type)
importFrom(sf,st_intersection)
importFrom(sf,st_intersects)
importFrom(sf,st_is_longlat)
importFrom(sf,st_is_valid)
importFrom(sf,st_join)
importFrom(sf,st_length)
importFrom(sf,st_line_merge)
importFrom(sf,st_make_grid)
importFrom(sf,st_point_on_surface)
importFrom(sf,st_reverse)
importFrom(sf,st_sf)
importFrom(sf,st_sfc)
importFrom(sf,st_union)
importFrom(sf,st_within)
importFrom(stats,integrate)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(utils,capture.output)
importFrom(utils,setTxtProgressBar)
importFrom(utils,strcapture)
importFrom(utils,txtProgressBar)
useDynLib(spNetwork)
useDynLib(spNetwork, .registration = TRUE)
